@@ -10,10 +10,13 @@
 #' @return A data.frame rounded to n significant digits.
 #' 
 #' @examples
+#' \dontrun{
 #' dfsigfig(mtcars,1)
+#' }
 #' 
 #' @export
 dfsigfig <- function(df, n=3) {
+    .Deprecated("mutate_if(is.numeric, signif, n)")
     df[ ,sapply(df, is.numeric)] <- signif(df[ ,sapply(df, is.numeric)], n)
     df
 }
